===================
Cover Rage - server
===================
.. image:: https://badge.fury.io/py/cover-rage-server.svg
    :target: https://badge.fury.io/py/cover-rage-server
.. image:: https://circleci.com/gh/alexryabtsev/cover_rage_server/tree/master.svg?style=shield
    :target: https://circleci.com/gh/alexryabtsev/cover_rage_server/tree/master

Server for `cover rage`_.

.. _cover rage: https://github.com/alexryabtsev/cover_rage
